@@ -7,6 +7,8 @@ from typing import Tuple
 from typing import Type
 from typing import Union
 
+from airflow.operators.bash import BashOperator
+
 from dkist_processing_core.task import TaskBase
 
 
@@ -16,7 +18,7 @@ upstreams_type_hint = Union[List[Type[TaskBase]], None, Type[TaskBase]]
 
 class Node:
     """
-    Abstraction to create a node in the implemented engine api (airflow)
+    Abstraction to create a node in the workflow graph as implemented by engine api (airflow)
     """
 
     def __init__(
@@ -46,24 +48,23 @@ class Node:
         self.upstreams = upstreams
 
     @property
-    def operator(self):
+    def operator(self) -> BashOperator:
         """
         Native engine node
         """
         from datetime import timedelta
-        from airflow.operators.bash import BashOperator
         from dkist_processing_core._failure_callback import chat_ops_notification
         from functools import partial
 
         return eval(self.operator_definition)
 
     @property
-    def operator_definition(self):
+    def operator_definition(self) -> str:
         return f"""BashOperator(
     task_id='{self.task.__name__}',
     bash_command='''{self._bash_script}''',
     retries={self.task.retries},
-    retry_delay=timedelta(minutes=1),
+    retry_delay=timedelta(seconds={self.task.retry_delay_seconds}),
     on_failure_callback=partial(
         chat_ops_notification,
         workflow_name='{self.workflow_name}',
@@ -82,7 +83,7 @@ class Node:
         return [(upstream.__name__, self.task.__name__) for upstream in self.upstreams]
 
     @property
-    def _bash_script(self):
+    def _bash_script(self) -> str:
         """
         Format bash script for the BashOperator
         """
@@ -108,7 +109,7 @@ echo Exit with code from main command: $exit_code
 exit $exit_code"""
 
     @property
-    def _install_command(self):
+    def _install_command(self) -> str:
         repo_name = self.workflow_package.split(".")[0].replace("_", "-")
         version = self.workflow_version
         artifact_folder = f"{repo_name}_{version}/"
@@ -116,11 +117,11 @@ exit $exit_code"""
         return f'pip install $CODE_MOUNT"{artifact_folder}{repo_name}"'
 
     @property
-    def _run_command(self):
+    def _run_command(self) -> str:
         return f'python -c "{self._python}"'
 
     @property
-    def _python(self):
+    def _python(self) -> str:
         return f"""from {self.task.__module__} import {self.task.__name__}
 with {self.task.__name__}(recipe_run_id={{{{dag_run.conf['recipe_run_id']}}}}, workflow_name='{self.workflow_name}', workflow_version='{self.workflow_version}') as task:
     task()
